==> cognite_pygen-0.14.0-py3-none-any.whl: cognite/pygen/_settings.py <==
from __future__ import annotations

import getpass
from pathlib import Path
from typing import Optional

from cognite.client import ClientConfig, CogniteClient
from cognite.client.credentials import OAuthClientCredentials

try:
    from pydantic import BaseModel, FieldValidationInfo, field_validator

    is_pydantic_v2 = True
except ImportError:
    from pydantic import BaseModel, validator

    is_pydantic_v2 = False


class Argument(BaseModel):
    default: Optional[str] = None
    help: str


def _parse_string(value: str, field) -> Argument:
    if value and isinstance(value, str):
        help_ = field.default.help
        return Argument(default=value, help=help_)
    return field.default


class PygenSettings(BaseModel):
    space: Argument = Argument(default=None, help="Location of Data Model")
    external_id: Argument = Argument(default=None, help="External ID of Data Model")
    version: Argument = Argument(default=None, help="Version of Data Model")
    tenant_id: Argument = Argument(default=None, help="Azure Tenant ID for connecting to CDF")
    client_id: Argument = Argument(default=None, help="Azure Client ID for connecting to CDF")
    cdf_cluster: Argument = Argument(default=None, help="CDF Cluster to connect to")
    cdf_project: Argument = Argument(default=None, help="CDF Project to connect to")
    output_dir: Argument = Argument(default=None, help="Output directory for generated SDK")
    top_level_package: Argument = Argument(default="my_domain.client", help="Package name for the generated client.")
    client_name: Argument = Argument(default="MyClient", help="Client name for the generated client.")

    if is_pydantic_v2:

        @field_validator("*", mode="before")
        def parse_string(cls, value, info: FieldValidationInfo) -> Argument:  # noqa: N805
            field = cls.model_fields[info.field_name]
            return _parse_string(value, field)

    else:

        @validator("*", pre=True)
        def parse_string(cls, value, field) -> Argument:
            return _parse_string(value, field)


def load_settings(pyproject_toml_path: Path) -> PygenSettings | None:
    if not pyproject_toml_path.exists():
        return None
    import toml

    pyproject_toml = toml.loads(pyproject_toml_path.read_text())
    if "pygen" in pyproject_toml.get("tool", {}):
        return PygenSettings(**pyproject_toml["tool"]["pygen"])
    return None


def get_cognite_client(project, cdf_cluster, tenant_id, client_id, client_secret):
    base_url = f"https://{cdf_cluster}.cognitedata.com/"
    credentials = OAuthClientCredentials(
        token_url=f"https://login.microsoftonline.com/{tenant_id}/oauth2/v2.0/token",
        client_id=client_id,
        client_secret=client_secret,
        scopes=[f"{base_url}.default"],
    )
    config = ClientConfig(
        project=project,
        credentials=credentials,
        client_name=getpass.getuser(),
        base_url=base_url,
    )
    return CogniteClient(config)


def load_cognite_client_from_toml(file_path: Path | str, section: str | None = "cognite") -> CogniteClient:
    import toml

    return get_cognite_client(**toml.load(Path(file_path))[section])

==> cognite_pygen-0.15.0-py3-none-any.whl: cognite/pygen/_settings.py <==
from __future__ import annotations

from pathlib import Path
from typing import Any, Optional

try:
    from pydantic import BaseModel, FieldValidationInfo, field_validator

    is_pydantic_v2 = True
except ImportError:
    from pydantic import BaseModel, validator

    is_pydantic_v2 = False


class Argument(BaseModel):
    default: Optional[str] = None
    help: str


def _parse_string(value: str, field) -> Argument:
    if value and isinstance(value, str):
        help_ = field.default.help
        return Argument(default=value, help=help_)
    return field.default


class PygenSettings(BaseModel):
    space: Argument = Argument(default=None, help="Location of Data Model")
    external_id: Argument = Argument(default=None, help="External ID of Data Model")
    version: Argument = Argument(default=None, help="Version of Data Model")
    tenant_id: Argument = Argument(default=None, help="Azure Tenant ID for connecting to CDF")
    client_id: Argument = Argument(default=None, help="Azure Client ID for connecting to CDF")
    cdf_cluster: Argument = Argument(default=None, help="CDF Cluster to connect to")
    cdf_project: Argument = Argument(default=None, help="CDF Project to connect to")
    output_dir: Argument = Argument(default=None, help="Output directory for generated SDK")
    top_level_package: Argument = Argument(default="my_domain.client", help="Package name for the generated client.")
    client_name: Argument = Argument(default="MyClient", help="Client name for the generated client.")

    if is_pydantic_v2:

        @field_validator("*", mode="before")
        def parse_string(cls, value, info: FieldValidationInfo) -> Argument:
            field = cls.model_fields[info.field_name]
            return _parse_string(value, field)

    else:

        @validator("*", pre=True)
        def parse_string(cls, value, field) -> Argument:
            return _parse_string(value, field)


def _load_pyproject_toml(pyproject_toml_path: Path | None = None) -> dict[str, Any]:
    if pyproject_toml_path is None:
        pyproject_toml_path = Path.cwd() / "pyproject.toml"
    if not pyproject_toml_path.exists():
        return {}
    import toml

    return toml.loads(pyproject_toml_path.read_text())


def load_settings(pyproject_toml_path: Path | None = None) -> PygenSettings | None:
    pyproject_toml = _load_pyproject_toml(pyproject_toml_path)
    if "pygen" in pyproject_toml.get("tool", {}):
        return PygenSettings(**pyproject_toml["tool"]["pygen"])
    return None
